Change Log
==========

0.0.1 (06/10/2020)
-------------------
-  First Release (Initial)
*  Prettified Tree Structure

0.0.2 (15/10/2020)
-------------------
-  Second Release
*  Added String Representation for GUI Log.

0.0.3 (05/02/2023)
-------------------
-  Third Release
*  Defining Directory Tree Depth.
*  Allows Hidden Entities [Files/Directories] to be Ignored.
*  Allows User to Hide the Header [OS / Path Info].

0.0.3.1 (09/03/2023)
-------------------
-  Bug Fix Release Under Third
*  Bug Fix for Hidden File Detection for Unix Based OSs
*  Minor README Modifications